@@ -1,3 +1,8 @@
+"""
+Utilities and base implementation of Connectors that allow a document to access a source native file or
+stream upon which the document is based or derived.
+"""
+
 import fnmatch
 import inspect
 import io
@@ -17,6 +22,7 @@ logger = logging.getLogger('kodexa.connectors')
 
 
 def get_caller_dir():
+    """ """
     # get the caller's stack frame and extract its file path
     frame_info = inspect.stack()[3]
     filepath = frame_info.filename
@@ -28,9 +34,11 @@ def get_caller_dir():
 
 
 class FolderConnector:
+    """ """
 
     @staticmethod
     def get_name():
+        """ """
         return "folder"
 
     def __init__(self, path, file_filter="*", recursive=False, relative=False, caller_path=get_caller_dir(),
@@ -50,6 +58,14 @@ class FolderConnector:
 
     @staticmethod
     def get_source(document):
+        """
+
+        Args:
+          document: 
+
+        Returns:
+
+        """
         return open(join(document.source.original_path, document.source.original_filename), 'rb')
 
     def __iter__(self):
@@ -93,9 +109,11 @@ class FolderConnector:
 
 
 class FileHandleConnector:
+    """ """
 
     @staticmethod
     def get_name():
+        """ """
         return 'file-handle'
 
     def __init__(self, original_path):
@@ -105,6 +123,14 @@ class FileHandleConnector:
 
     @staticmethod
     def get_source(document):
+        """
+
+        Args:
+          document: 
+
+        Returns:
+
+        """
         return open(document.source.original_path, 'rb')
 
     def __iter__(self):
@@ -127,9 +153,11 @@ class FileHandleConnector:
 
 
 class UrlConnector:
+    """ """
 
     @staticmethod
     def get_name():
+        """ """
         return "url"
 
     def __init__(self, original_path, headers=None):
@@ -142,6 +170,14 @@ class UrlConnector:
 
     @staticmethod
     def get_source(document):
+        """
+
+        Args:
+          document: 
+
+        Returns:
+
+        """
 
         # If we have an http URL then we should use requests, it is much
         # cleaner
@@ -182,16 +218,36 @@ registered_connectors: Dict[str, Type] = {}
 
 
 class CacheConnector:
-    """
-    A Cache Connector can be used to inject caching of content
+    """A Cache Connector can be used to inject caching of content
     in front of a connector, you must extend this type to implement
     a cache
+
+    Args:
+
+    Returns:
+
     """
 
     def is_cached(self, source: SourceMetadata):
+        """
+
+        Args:
+          source: SourceMetadata: 
+
+        Returns:
+
+        """
         return False
 
     def get_source(self, document: Document):
+        """
+
+        Args:
+          document: Document: 
+
+        Returns:
+
+        """
         pass
 
 
@@ -201,25 +257,40 @@ registered_caches: List[CacheConnector] = []
 
 def get_connectors():
     """
-    Return a list of the registered connectors
 
-    :return:
+    Args:
+
+    Returns:
+      :return:
+
     """
     return registered_connectors.keys()
 
 
 def add_cache(cache_connector: CacheConnector):
-    """
-    Register a cache connector, this can intercept a source request and
+    """Register a cache connector, this can intercept a source request and
     determine if there is already an object in a cache that holds it
 
-    :param cache_connector:
-    :return:
+    Args:
+      cache_connector: return:
+      cache_connector: CacheConnector: 
+
+    Returns:
+
     """
     registered_caches.append(cache_connector)
 
 
 def get_connector(connector: str, source: SourceMetadata):
+    """
+
+    Args:
+      connector: str: 
+      source: SourceMetadata: 
+
+    Returns:
+
+    """
     # Adding support for cache connectors
     for cache_connector in registered_caches:
         if cache_connector.is_cached(source):
@@ -234,16 +305,33 @@ def get_connector(connector: str, source: SourceMetadata):
 
 
 def add_connector(connector):
+    """
+
+    Args:
+      connector: 
+
+    Returns:
+
+    """
     registered_connectors[connector.get_name()] = connector
 
 
 def get_source(document):
+    """
+
+    Args:
+      document: 
+
+    Returns:
+
+    """
     connector = get_connector(document.source.connector,
                               document.source)
     return connector.get_source(document)
 
 
 class DocumentStoreConnector(object):
+    """ """
 
     def __init__(self, store: DocumentStore, subscription: str):
         self.store = store
@@ -252,6 +340,7 @@ class DocumentStoreConnector(object):
 
     @staticmethod
     def get_name():
+        """ """
         return "document-store"
 
     def __iter__(self):
@@ -267,6 +356,14 @@ class DocumentStoreConnector(object):
 
     @staticmethod
     def get_source(document):
+        """
+
+        Args:
+          document: 
+
+        Returns:
+
+        """
         from kodexa import RemoteDocumentStore
         remote_document_store = RemoteDocumentStore(document.source.headers['ref'])
         bytes = remote_document_store.get_source(document.source.headers['id'])
