@@ -1,7 +1,4 @@
 """
-Sinks
------
-
 Sinks are the end-point of a Pipeline and allow for the final output of the pipeline to be either stored or written
 out
 """
