@@ -5,17 +5,29 @@ from kodexa.model.document_families import ContentEvent
 
 
 class TestAction:
+    """ """
 
     def __init__(self, cheese: str = None):
         self.cheese = cheese
 
     def get_name(self):
+        """ """
         return "Hello"
 
 
 class TestAssistant(Assistant):
+    """ """
 
     def process_event(self, event: ContentEvent, context: AssistantContext = None) -> List[Pipeline]:
+        """
+
+        Args:
+          event: ContentEvent: 
+          context: AssistantContext:  (Default value = None)
+
+        Returns:
+
+        """
         # This is just an example of an assistant
         # basically we are just going to return a pipeline that
         # adds a label to the document - creating a new version
