@@ -1,7 +1,4 @@
 """
-Workflows
----------
-
 Support for setting up and defining workflows that you can deploy
 """
 from .workflow import Workflow, CronSchedule, WebSchedule, StorePublisher
